@@ -1,12 +1,12 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) 2007-2012 Daniel C. Bünzli. All rights reserved.
+   Copyright 2007 Daniel C. Bünzli. All rights reserved.
    Distributed under a BSD3 license, see license at the end of the file.
-   xmlm release 1.1.1
+   xmlm release 1.2.0
   ---------------------------------------------------------------------------*)
 
-(** Streaming XML IO.  
+(** Streaming XML codec.  
 
-    A well-formed sequence of {{:#TYPEsignal}signals} represents an
+    A well-formed sequence of {{!signal}signals} represents an
     {{:http://www.w3.org/TR/REC-xml}XML} document tree traversal in
     depth first order (this has nothing to do with XML
     well-formedness). Input pulls a well-formed sequence of signals
@@ -14,10 +14,10 @@
     signals to a data destination. Functions are provided to easily 
     transform sequences of signals to/from arborescent data structures.
 
-    Consult the {{:#io}features and limitations} and {{:#ex}examples} 
+    Consult the {{!io}features and limitations} and {{!ex}examples} 
     of use.
 
-    {e Release 1.1.1 - Daniel Bünzli <daniel.buenzli at erratique.ch> }
+    {e Release 1.2.0 — Daniel Bünzli <daniel.buenzl i\@erratique.ch> }
 
     {3 References}
     {ul
@@ -73,7 +73,7 @@ child ::= `Data | tree | epsilon ]}
 val ns_xml : string 
 (** Namespace name {{:http://www.w3.org/XML/1998/namespace}value} bound to the 
     reserved ["xml"] prefix. *)
-
+  
 val ns_xmlns : string
 (** Namespace name {{:http://www.w3.org/2000/xmlns/}value} bound to the 
     reserved ["xmlns"] prefix. *)
@@ -95,9 +95,9 @@ type error = [
   | `Unknown_encoding of string 
   (** Unknown encoding. *)
   | `Unknown_entity_ref of string 
-  (** Unknown entity reference, {{:#inentity} details}. *)
+  (** Unknown entity reference, {{!inentity} details}. *)
   | `Unknown_ns_prefix of string 
-  (** Unknown namespace prefix {{:#inns} details} *)
+  (** Unknown namespace prefix {{!inns} details} *)
   | `Illegal_char_ref of string 
   (** Illegal character reference. *)
   | `Illegal_char_seq of string 
@@ -124,31 +124,33 @@ type input
 (** The type for input abstractions. *)
 
 val make_input : ?enc:encoding option -> ?strip:bool -> 
-                 ?ns:(string -> string option) -> 
-		 ?entity: (string -> string option) -> source -> input
+  ?ns:(string -> string option) -> 
+  ?entity: (string -> string option) -> source -> input
 (** Returns a new input abstraction reading from the given source.
     {ul 
-    {- [enc], character encoding of the document, {{:#inenc} details}. 
+    {- [enc], character encoding of the document, {{!inenc} details}. 
        Defaults to [None].}
-    {- [strip], strips whitespace in character data, {{:#inwspace} details}.
+    {- [strip], strips whitespace in character data, {{!inwspace} details}.
        Defaults to [false].} 
     {- [ns] is called to bind undeclared namespace prefixes,
-       {{:#inns} details}. Default returns always [None].}
+       {{!inns} details}. Default returns always [None].}
     {- [entity] is called to resolve non predefined entity references,
-       {{:#inentity} details}. Default returns always [None].}} *)
-
+       {{!inentity} details}. Default returns always [None].}} *)
+  
 val input : input -> signal
 (** Inputs a signal. Repeated invocation of the function with the same
-    input abstraction will generate a {{:#TYPEsignal}well-formed} sequence
+    input abstraction will generate a {{!signal}well-formed} sequence
     of signals or an {!Error} is raised. Furthermore there will be no
     two consecutive [`Data] signals in the sequence and their string
-    is always non empty. After a well-formed sequence was input another may 
-    be input, see {!eoi} and {{:#iseq}details}.
-
+    is always non empty. 
+    
+    {b Deprecated} After a well-formed sequence was input another may 
+    be input, see {!eoi} and {{!iseq}details}.
+    
     {b Raises} {!Error} on input errors. *)
-
+  
 val input_tree : el:(tag -> 'a list -> 'a) -> data:(string -> 'a)  -> 
-                 input -> 'a
+  input -> 'a
 (** If the next signal is a :
     {ul
     {- [`Data] signal, inputs it and invokes [data] with the character data.}
@@ -167,21 +169,21 @@ val input_tree : el:(tag -> 'a list -> 'a) -> data:(string -> 'a)  ->
       if the next signal is not [`El_start] or [`Data]. *)
 
 val input_doc_tree : el:(tag -> 'a list -> 'a) -> data:(string -> 'a) -> 
-                     input -> (dtd * 'a)
-(** Same as {!input_tree} but reads a complete {{:#TYPEsignal}well-formed}  
+  input -> (dtd * 'a)
+(** Same as {!input_tree} but reads a complete {{!signal}well-formed}  
     sequence of signals. 
-
+    
     {b Raises} {!Error} on input errors and [Invalid_argument]
      if the next signal is not [`Dtd]. *)
-    
+           
 val peek : input -> signal
 (** Same as {!input} but doesn't remove the signal from the sequence. 
-
+    
     {b Raises} {!Error} on input errors. *)
-
+  
 val eoi : input -> bool
-(** Returns [true] if the end of input is reached. See {{:#iseq}details}.
- 
+(** Returns [true] if the end of input is reached. See {{!iseq}details}.
+    
     {b Raises} {!Error} on input errors. *)
 
 val pos : input -> pos 
@@ -192,17 +194,17 @@ val pos : input -> pos
 type 'a frag = [ `El of tag * 'a list | `Data of string ]
 (** The type for deconstructing data structures of type ['a]. *)
 
-type dest = [ `Channel of out_channel | `Buffer of Buffer.t | 
-              `Fun of (int -> unit) ]
+type dest = [ `Channel of out_channel | `Buffer of Buffer.t 
+            | `Fun of (int -> unit) ]
 (** The type for output destinations. For [`Buffer], the buffer won't
     be cleared. For [`Fun] the function is called with the output {e
     bytes} as [int]s. *)
-
+            
 type output
 (** The type for output abstractions. *)
-
+  
 val make_output : ?decl:bool -> ?nl:bool -> ?indent:int option -> 
-                  ?ns_prefix:(string -> string option) -> dest -> output
+  ?ns_prefix:(string -> string option) -> dest -> output
 (** Returns a new output abstraction writing to the given destination.
     {ul 
     {- [decl], if [true] the {{:http://www.w3.org/TR/REC-xml/#NT-XMLDecl} XML
@@ -210,37 +212,41 @@ val make_output : ?decl:bool -> ?nl:bool -> ?indent:int option ->
     {- [nl], if [true] a newline is output when the root's element [`El_end] 
      signal is output.
     Defaults to [false].}
-    {- [indent], identation behaviour, see {{:#outindent} details}. Defaults to
+    {- [indent], identation behaviour, see {{!outindent} details}. Defaults to
       [None].}
     {- [ns_prefix], undeclared namespace prefix bindings, 
-       see {{:#outns}details}. Default returns always [None].}} *)
-
+       see {{!outns}details}. Default returns always [None].}} *)
 
 val output : output -> signal -> unit
-(** Outputs a signal. After a well-formed sequence of signals was 
-    output a new well-formed sequence can be output.
+(** Outputs a signal. 
+
+    {b Deprecated.} After a well-formed sequence of signals was output
+    a new well-formed sequence can be output.
 
     {b Raises} [Invalid_argument] if the resulting signal sequence on
-    the output abstraction is not {{:#TYPEsignal}well-formed} or if a
+    the output abstraction is not {{!signal}well-formed} or if a
     namespace name could not be bound to a prefix. *)
 
 val output_depth : output -> int
 (** [output_depth o] is [o]'s current element nesting level (undefined
     before the first [`El_start] and after the last [`El_end]). *)
-
+  
 val output_tree : ('a -> 'a frag) -> output -> 'a -> unit
 (** Outputs signals corresponding to a value by recursively
     applying the given value deconstructor.
-
+    
     {b Raises} see {!output}. *)
-
+  
 val output_doc_tree : ('a -> 'a frag) -> output -> (dtd * 'a) -> unit   
-(** Same as {!output_tree} but outputs a complete {{:#TYPEsignal}well-formed} 
+(** Same as {!output_tree} but outputs a complete {{!signal}well-formed} 
     sequence of signals.
 
     {b Raises} see {!output}. *)
 
-(** {1:sto Functorial interface} 
+(** {1:sto Functorial interface (deprecated)} 
+
+    {b WARNING.} The functioral interface is deprecated and will be 
+    removed.
 
     {!Make} allows client to specify types for strings and internal
     buffers. Among other things this can be used to perform
@@ -255,13 +261,13 @@ module type String = sig
   
   type t
   (** The type for strings. *)
-
+    
   val empty : t
   (** The empty string. *)
-	
+  
   val length : t -> int
   (** Returns the length of the string. *)
-	
+  
   val append : t -> t -> t
   (** Concatenates two strings. *)
 
@@ -291,13 +297,13 @@ module type Buffer = sig
 
   type string
   (** The type for strings. *)
-	
+    
   type t 
   (** The type for buffers. *)
 
   exception Full
   (** Raised if the buffer cannot be grown. *)
-	  
+    
   val create : int -> t
   (** Creates a buffer of the given size. *)
 
@@ -310,7 +316,7 @@ module type Buffer = sig
 
   val clear : t -> unit
   (** Clears the buffer. *)
-
+    
   val contents : t -> string
   (** Returns the buffer contents. *)
   
@@ -324,7 +330,7 @@ module type S = sig
   (** {1 Basic types and values} *)  
 
   type string 
-
+    
   type encoding = [ 
     | `UTF_8 | `UTF_16 | `UTF_16BE | `UTF_16LE | `ISO_8859_1| `US_ASCII ]
   type dtd = string option
@@ -332,7 +338,7 @@ module type S = sig
   type attribute = name * string
   type tag = name * attribute list
   type signal = [ `Dtd of dtd | `El_start of tag | `El_end | `Data of string ]
-	
+  
   val ns_xml : string 
   val ns_xmlns : string
       
@@ -340,17 +346,17 @@ module type S = sig
 
   type pos = int * int 
   type error = [
-    | `Max_buffer_size			
+    | `Max_buffer_size      
     | `Unexpected_eoi
     | `Malformed_char_stream
     | `Unknown_encoding of string
-    | `Unknown_entity_ref of string				 
-    | `Unknown_ns_prefix of string				
+    | `Unknown_entity_ref of string        
+    | `Unknown_ns_prefix of string        
     | `Illegal_char_ref of string 
     | `Illegal_char_seq of string 
     | `Expected_char_seqs of string list * string
     | `Expected_root_element ]
-	
+  
   exception Error of pos * error
   val error_message : error -> string
 
@@ -360,33 +366,33 @@ module type S = sig
   | `Fun of (unit -> int) ]
 
   type input
-
-  val make_input : ?enc:encoding option -> ?strip:bool -> 
-                   ?ns:(string -> string option) -> 
-		   ?entity: (string -> string option) -> source -> input
-
-  val input : input -> signal
-
-  val input_tree : el:(tag -> 'a list -> 'a) -> data:(string -> 'a)  -> 
-                   input -> 'a
-
-  val input_doc_tree : el:(tag -> 'a list -> 'a) -> data:(string -> 'a) -> 
-                       input -> (dtd * 'a)
     
+  val make_input : ?enc:encoding option -> ?strip:bool -> 
+    ?ns:(string -> string option) -> 
+    ?entity: (string -> string option) -> source -> input
+    
+  val input : input -> signal
+    
+  val input_tree : el:(tag -> 'a list -> 'a) -> data:(string -> 'a)  -> 
+    input -> 'a
+    
+  val input_doc_tree : el:(tag -> 'a list -> 'a) -> data:(string -> 'a) -> 
+    input -> (dtd * 'a)
+             
   val peek : input -> signal
   val eoi : input -> bool
   val pos : input -> pos 
-
+    
   (** {1 Output} *)
-
+    
   type 'a frag = [ `El of tag * 'a list | `Data of string ]
   type dest = [ 
     | `Channel of out_channel | `Buffer of std_buffer | `Fun of (int -> unit) ]
-
+  
   type output
   val make_output : ?decl:bool -> ?nl:bool -> ?indent:int option -> 
-                    ?ns_prefix:(string -> string option) -> dest -> output
-
+    ?ns_prefix:(string -> string option) -> dest -> output
+    
   val output_depth : output -> int
   val output : output -> signal -> unit
   val output_tree : ('a -> 'a frag) -> output -> 'a -> unit
@@ -395,8 +401,8 @@ end
 
 (** Functor building streaming XML IO with the given strings and buffers. *)
 module Make (String : String) (Buffer : Buffer with type string = String.t) : S
-with type string = String.t
-
+  with type string = String.t
+                       
 (** {1:io Features and limitations}
     
     The module assumes strings are immutable, thus strings
@@ -412,7 +418,7 @@ with type string = String.t
     {{:http://www.faqs.org/rfcs/rfc2781.html} UTF-16BE} and
     {{:http://anubis.dkuug.dk/JTC1/SC2/WG3/docs/n411.pdf}ISO-8559-1} 
     (Latin-1) encoded documents. But strings returned by
-    the library are {b always} UTF-8 encoded (unless you use the functor). 
+    the library are {b always} UTF-8 encoded. 
     
     The encoding can be specified explicitly using the optional
     argument [enc]. Otherwise the parser uses UTF-16 or UTF-8 if there is a
@@ -440,7 +446,7 @@ with type string = String.t
     {{:http://www.w3.org/TR/REC-xml/#sec-line-ends}line ends} are
     translated to the newline character ([U+000A]).  {3:inns Namespaces}
 
-    Xmlm's {{:#TYPEname}names} are
+    Xmlm's {{!name}names} are
     {{:http://www.w3.org/TR/xml-names11/#dt-expname}expanded names}.
     The parser automatically handles the document's namespace
     declarations.  Undeclared namespace prefixes can be bound via the
@@ -458,18 +464,22 @@ with type string = String.t
     prefixes by documents, the parser does not report errors on violations 
     of the {i must} constraints listed in
     {{:http://www.w3.org/TR/xml-names11/#xmlReserved}this paragraph}. 
+
     {3:inentity Character and entity references}
 
     {{:http://www.w3.org/TR/REC-xml/#dt-charref}Character references}
     and {{:http://www.w3.org/TR/REC-xml/#sec-predefined-ent}predefined
     entities} are automatically resolved. Other entity references can
     be resolved by the callback [entity], which must return an UTF-8
-    (unless you use the functor) string corresponding to the
+    string corresponding to the
     replacement character data.  The replacement data is {e not}
     analysed for further references, it is added to the data as such
     modulo white space stripping. If [entity] returns [None] the error
     [`Unknown_entity_ref] is returned.    
-    {3:iseq Sequences of documents}
+
+    {3:iseq Sequences of documents (deprecated)}
+
+    {b WARNING.} This feature is deprecated and will be removed.
 
     When a well-formed sequence of signals is input, no data is consumed beyond
     the closing ['>'] of the document's root element. 
@@ -504,21 +514,24 @@ with type string = String.t
     {{:http://www.w3.org/TR/REC-xml/#sec-rmd}standalone declaration}.}
     {- Element attributes are not checked for uniqueness.}
     {- Attribute and character data chunks are limited by 
-       [Sys.max_string_length] (unless you use the functor). 
+       [Sys.max_string_length]. 
        The error [`Max_buffer_size] is raised if the limit is hit.}
     {- Tail recursive.}
     {- Non validating.}
     }
     
-
     {2:output Output} 
     {3:outenc Encoding} 
 
     Outputs only {{:http://www.faqs.org/rfcs/rfc3629.html} UTF-8}
-    encoded documents (even if you use the functor).  Strings given to
-    output functions {b must be} UTF-8 encoded (unless you use the
-    functor, but you need to provide a translation), no checks are
-    performed.  {3:outns Namespaces}
+    encoded documents.  Strings given to
+    output functions {b must be} UTF-8 encoded, no checks are
+    performed. Unicode characters that are not legal XML
+    {{:http://www.w3.org/TR/REC-xml/#NT-Char}characters} are replaced
+    by the {{:http://unicode.org/glossary/#replacement_character}Unicode 
+    replacement character}.
+
+    {3:outns Namespaces}
 
     Xmlm's {{:#TYPEname}names} are
     {{:http://www.w3.org/TR/xml-names11/#dt-expname}expanded names}.
@@ -557,7 +570,10 @@ let ex_ns = (Xmlm.ns_xmlns, "ex"), "http://example.org/ex"]}
        (for empty elements [`El_start] and [`El_end] are collapsed on a single
        line) and nested elements are indented with [c] space
        characters.
-    {3:oseq Sequences of documents} 
+
+    {3:oseq Sequences of documents (deprecated)} 
+
+    {b WARNING.} This feature is deprecated and will be removed.
 
     After a well-formed sequence of signals was output, the output
     abstraction can be reused to output a new well-formed sequence of
@@ -765,7 +781,7 @@ let out_w3c_bureaucrats dst bl =
 *)
 
 (*---------------------------------------------------------------------------
-  Copyright (c) 2007-2012 Daniel C. Bünzli
+  Copyright 2007 Daniel C. Bünzli
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
