@@ -1,6 +1,7 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) 2007-2012 Daniel C. Bünzli. All rights reserved.
+   Copyright 2007 Daniel C. Bünzli. All rights reserved.
    Distributed under a BSD3 license, see license at the end of the file.
+   xmlm release 1.2.0
   ---------------------------------------------------------------------------*)
 
 let str = Printf.sprintf
@@ -10,16 +11,16 @@ let apply f x ~finally y =
   let result = try f x with exn -> finally y; raise exn in
   finally y;
   result
-
+  
 let fail ((l, c), e) = failwith (str "%d:%d: %s" l c (Xmlm.error_message e))
-
+    
 type tree = E of Xmlm.tag * tree list | D of string
-
+              
 let in_tree i = 
   let el tag childs = E (tag, childs)  in
   let data d = D d in
   Xmlm.input_doc_tree ~el ~data i
-
+    
 let out_tree o t = 
   let frag = function
   | E (tag, childs) -> `El (tag, childs) 
@@ -44,7 +45,7 @@ let xml_parse tree enc strip entity ns ic () =                (* parse only *)
   in
   try while not (Xmlm.eoi i) do doc i done 
   with Xmlm.Error (p, e) -> fail (p, e)
-
+                              
 let xml_signals _ enc strip entity ns ic _ =           (* output signals *)
   let pr s = Printf.fprintf stdout s in
   let i = Xmlm.make_input ~enc ~strip ~entity ~ns (`Channel ic) in 
@@ -76,36 +77,36 @@ let xml_outline tree enc strip entity ns ic oc =            (* ascii outline *)
   let doc i = 
     if tree then 
       begin 
-	let rec pr_tree d = function
-	  | (n :: next) :: path -> 
-	      begin match n with
-	      | D data -> pr_data d data; pr_tree d (next :: path)
-	      | E (tag, childs) -> 
-		  pr_tag d tag; pr_tree (d+1) (childs :: next :: path)
-	      end
-	  | [] :: path -> if d = 0 then () else pr_tree (d - 1) path
-	  | _ -> assert false
-	in
-	let dtd, t = in_tree i in
-	pr_dtd dtd;
-	pr_tree 0 ([t] :: [])
+        let rec pr_tree d = function
+        | (n :: next) :: path -> 
+            begin match n with
+            | D data -> pr_data d data; pr_tree d (next :: path)
+            | E (tag, childs) -> 
+                pr_tag d tag; pr_tree (d+1) (childs :: next :: path)
+            end
+        | [] :: path -> if d = 0 then () else pr_tree (d - 1) path
+        | _ -> assert false
+        in
+        let dtd, t = in_tree i in
+        pr_dtd dtd;
+        pr_tree 0 ([t] :: [])
       end
     else
-      begin 
-	let rec pull i l = match Xmlm.input i with
-	| `El_start tag -> pr_tag l tag; pull i (l + 1)
-	| `El_end -> if l = 1 then () else pull i (l - 1)
-	| `Data d -> pr_data l d; pull i l
-	| `Dtd _ -> assert false 
-	  in
-	pr_dtd (match Xmlm.input i with `Dtd d -> d | _ -> assert false);
-	pull i 0;
-      end;
+    begin 
+      let rec pull i l = match Xmlm.input i with
+      | `El_start tag -> pr_tag l tag; pull i (l + 1)
+      | `El_end -> if l = 1 then () else pull i (l - 1)
+      | `Data d -> pr_data l d; pull i l
+      | `Dtd _ -> assert false 
+      in
+      pr_dtd (match Xmlm.input i with `Dtd d -> d | _ -> assert false);
+      pull i 0;
+    end;
     flush oc
   in
   try while not (Xmlm.eoi i) do doc i done
   with Xmlm.Error (p, e) -> fail (p, e)
-
+                              
 let xml_xml indent tree enc strip entity ns ic oc =              (* xml trip *)
   let nl = (indent = None) in
   let i = Xmlm.make_input ~enc ~strip ~ns ~entity (`Channel ic) in
@@ -114,13 +115,13 @@ let xml_xml indent tree enc strip entity ns ic oc =              (* xml trip *)
     if tree then (out_tree o (in_tree i)) else
     begin 
       let rec pull i o depth = 
-	let s = Xmlm.input i in
-	Xmlm.output o s;
-	match s with 
-	| `El_start _ -> pull i o (depth + 1)
-	| `El_end -> if depth = 1 then () else pull i o (depth - 1)
-	| `Data _ -> pull i o depth 
-	| `Dtd _ -> assert false
+        let s = Xmlm.input i in
+        Xmlm.output o s;
+        match s with 
+        | `El_start _ -> pull i o (depth + 1)
+        | `El_end -> if depth = 1 then () else pull i o (depth - 1)
+        | `Data _ -> pull i o depth 
+        | `Dtd _ -> assert false
       in
       Xmlm.output o (Xmlm.input i); (* `Dtd *)
       pull i o 0
@@ -128,7 +129,7 @@ let xml_xml indent tree enc strip entity ns ic oc =              (* xml trip *)
   in
   try while not (Xmlm.eoi i) do doc i o done 
   with Xmlm.Error (p, e) -> fail (p, e)
-
+                              
 let with_inf f inf v = 
   try
     let ic = if inf <> "" then open_in_bin inf else stdin in 
@@ -137,7 +138,7 @@ let with_inf f inf v =
   with
   | Sys_error e -> pr_err (str " %s" e)
   | Failure e -> pr_err (str "%s:%s" inf e)
-	
+                   
 let with_outf f ic outf = 
   try 
     let oc = if outf <> "" then open_out_bin outf else stdout in 
@@ -145,36 +146,36 @@ let with_outf f ic outf =
     apply (f ic) oc ~finally:close oc
   with
   | Sys_error e -> pr_err (str " %s" e)
-
+                     
 let entity_fun eref xhtml = 
   if not xhtml then (if eref then fun x -> Some x else fun x -> None) else
   let h = Hashtbl.create 270 in
   List.iter (fun (e, ustr) -> Hashtbl.add h e ustr) Xhtml.entities;
   if eref then (fun x -> try Some (Hashtbl.find h x) with Not_found -> Some x)
   else (fun x -> try Some (Hashtbl.find h x) with Not_found -> None)
-        
+    
 let process signals tree enc strip eref ns xhtml parse_only outline indent 
-            suffix files = 
+    suffix files = 
   let entity = entity_fun eref xhtml in
   let ns = if ns then fun x -> Some x else fun x -> None in
   let f = 
     if parse_only then 
       fun inf -> with_inf (xml_parse tree enc strip entity ns) inf ()
     else 
-      let outf inf =  
-	if inf = "" || suffix = "" then "" (* stdout *) else 
-	str "%s.%s" inf suffix 
-      in
-      let f = 
-	if outline then xml_outline else 
-	if signals then xml_signals else
-	(xml_xml indent) 
-      in
-      fun inf -> 
-	with_inf (with_outf (f tree enc strip entity ns)) inf (outf inf)
+    let outf inf =  
+      if inf = "" || suffix = "" then "" (* stdout *) else 
+      str "%s.%s" inf suffix 
+    in
+    let f = 
+      if outline then xml_outline else 
+      if signals then xml_signals else
+      (xml_xml indent) 
+    in
+    fun inf -> 
+      with_inf (with_outf (f tree enc strip entity ns)) inf (outf inf)
   in
   List.iter f files
-
+    
 let encoding_of_str enc = match (String.lowercase enc) with
 | "" -> None
 | "utf-8" | "utf8" | "utf_8" -> Some `UTF_8
@@ -185,7 +186,7 @@ let encoding_of_str enc = match (String.lowercase enc) with
 | "iso_8859_1" | "latin1" | "latin-1" -> Some `ISO_8859_1 
 | "ascii" | "us-ascii" -> Some `US_ASCII
 | e -> pr_err (str "unknown encoding '%s', trying to guess." e); None
-
+    
 let main () = 
   let usage = 
     str "Usage: %s <options> <files>\n\
@@ -240,7 +241,7 @@ let main () =
 let () = main ()
 
 (*---------------------------------------------------------------------------
-  Copyright (c) 2007-2012 Daniel C. Bünzli
+  Copyright 2007 Daniel C. Bünzli
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
